@@ -1,6 +1,6 @@
 /*
-Copyright (c) 2008-2010
-	Lars-Dominik Braun <PromyLOPh@lavabit.com>
+Copyright (c) 2008-2012
+	Lars-Dominik Braun <lars@6xq.net>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -21,22 +21,13 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 */
 
-#ifndef _SETTINGS_H
-#define _SETTINGS_H
+#pragma once
+
+#include <stdbool.h>
 
 #include <piano.h>
-#include <waitress.h>
 
-#include "player.h"
-
-#define BAR_KS_ARGS PianoHandle_t *ph, WaitressHandle_t *waith, \
-		struct audioPlayer *player, \
-		BarSettings_t *settings, PianoSong_t **curSong, \
-		PianoStation_t **curStation, PianoSong_t **songHistory, char *doQuit, \
-		FILE *curFd
-
-/* keep in mind that you have to update several arrays in main.c/ui_act.c too,
- * if you're adding new shortcuts */
+/* update structure in ui_dispatch.h if you add shortcuts here */
 typedef enum {
 	BAR_KS_HELP = 0,
 	BAR_KS_LOVE = 1,
@@ -49,37 +40,77 @@ typedef enum {
 	BAR_KS_HISTORY = 8,
 	BAR_KS_INFO = 9,
 	BAR_KS_ADDSHARED = 10,
-	BAR_KS_MOVESONG = 11,
-	BAR_KS_SKIP = 12,
-	BAR_KS_PLAYPAUSE = 13,
-	BAR_KS_QUIT = 14,
-	BAR_KS_RENAMESTATION = 15,
-	BAR_KS_SELECTSTATION = 16,
-	BAR_KS_TIRED = 17,
-	BAR_KS_UPCOMING = 18,
-	BAR_KS_SELECTQUICKMIX = 19,
-	BAR_KS_DEBUG = 20,
-	BAR_KS_BOOKMARK = 21,
+	BAR_KS_SKIP = 11,
+	BAR_KS_PLAYPAUSE = 12,
+	BAR_KS_QUIT = 13,
+	BAR_KS_RENAMESTATION = 14,
+	BAR_KS_SELECTSTATION = 15,
+	BAR_KS_TIRED = 16,
+	BAR_KS_UPCOMING = 17,
+	BAR_KS_SELECTQUICKMIX = 18,
+	BAR_KS_DEBUG = 19,
+	BAR_KS_BOOKMARK = 20,
+	BAR_KS_VOLDOWN = 21,
+	BAR_KS_VOLUP = 22,
+	BAR_KS_MANAGESTATION = 23,
+	BAR_KS_PLAYPAUSE2 = 24,
+	BAR_KS_CREATESTATIONFROMSONG = 25,
+	BAR_KS_PLAY = 26,
+	BAR_KS_PAUSE = 27,
+	BAR_KS_VOLRESET = 28,
+	BAR_KS_SETTINGS = 29,
 	/* insert new shortcuts _before_ this element and increase its value */
-	BAR_KS_COUNT = 22,
+	BAR_KS_COUNT = 30,
 } BarKeyShortcutId_t;
 
+#define BAR_KS_DISABLED '\x00'
+
+typedef enum {
+	BAR_SORT_NAME_AZ = 0,
+	BAR_SORT_NAME_ZA = 1,
+	BAR_SORT_QUICKMIX_01_NAME_AZ = 2,
+	BAR_SORT_QUICKMIX_01_NAME_ZA = 3,
+	BAR_SORT_QUICKMIX_10_NAME_AZ = 4,
+	BAR_SORT_QUICKMIX_10_NAME_ZA = 5,
+	BAR_SORT_COUNT = 6,
+} BarStationSorting_t;
+
 typedef struct {
+	char *prefix;
+	char *postfix;
+} BarMsgFormatStr_t;
+
+#include "ui_types.h"
+
+typedef struct {
+	bool autoselect;
+	unsigned int history, maxRetry, timeout;
+	int volume;
+	float gainMul;
+	BarStationSorting_t sortOrder;
+	PianoAudioQuality_t audioQuality;
 	char *username;
-	char *password;
+	char *password, *passwordCmd;
 	char *controlProxy; /* non-american listeners need this */
-	char keys[BAR_KS_COUNT];
-	PianoAudioFormat_t audioFormat;
+	char *proxy;
+	char *bindTo;
 	char *autostartStation;
 	char *eventCmd;
-	unsigned int history;
+	char *loveIcon, *banIcon, *tiredIcon;
+	char *atIcon;
+	char *npSongFormat;
+	char *npStationFormat;
+	char *listSongFormat;
+	char *fifo;
+	char *rpcHost, *rpcTlsPort, *partnerUser, *partnerPassword, *device, *inkey, *outkey, *caBundle;
+	char keys[BAR_KS_COUNT];
+	BarMsgFormatStr_t msgFormat[MSG_COUNT];
 } BarSettings_t;
 
-typedef void (*BarKeyShortcutFunc_t) (BAR_KS_ARGS);
+#include <piano.h>
 
 void BarSettingsInit (BarSettings_t *);
 void BarSettingsDestroy (BarSettings_t *);
 void BarSettingsRead (BarSettings_t *);
-void BarGetXdgConfigDir (const char *, char *, size_t);
+void BarSettingsWrite (PianoStation_t *, BarSettings_t *);
 
-#endif /* _SETTINGS_H */
